#include <gtk/gtk.h>


void
on_page1_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page1_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page2_register_button_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_page2_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page2_connect_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page3_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page3_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page4_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page4_connect_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_window_destroy                      (GtkObject       *object,
                                        gpointer         user_data);
